@@ -39,7 +39,8 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
     try {
         switch ($_POST['action']) {
             case 'get_backup_files':
-                $result = ['success' => true, 'files' => getAvailableBackupFiles()];
+                $targetUser = $_POST['target_user'] ?? null;
+                $result = ['success' => true, 'files' => getAvailableBackupFiles($targetUser)];
                 echo json_encode($result);
                 break;
                 
@@ -77,8 +78,14 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
     exit;
 }
 
-function getAvailableBackupFiles() {
-    $userfilesDir = '/docker/users/' . AUTH_USER . '/userfiles';
+function getAvailableBackupFiles($targetUser = null) {
+    // Determine which user's directory to scan
+    $username = AUTH_USER;
+    if (AUTH_USER === 'root' && $targetUser) {
+        $username = $targetUser;
+    }
+    
+    $userfilesDir = '/docker/users/' . $username . '/userfiles';
     $backupFiles = [];
     
     if (is_dir($userfilesDir)) {
