@@ -617,6 +617,12 @@ class haproxy_manager {
             return false;
         }
         
+        // Check if IP is already blocked to avoid unnecessary API calls
+        if ($this->is_ip_blocked($ip_address)) {
+            // IP is already blocked, no need to send duplicate block command
+            return true;
+        }
+        
         $data = [
             'ip_address' => $ip_address,
             'reason' => $reason,
@@ -650,6 +656,12 @@ class haproxy_manager {
             return false;
         }
         
+        // Check if IP is actually blocked before trying to unblock
+        if (!$this->is_ip_blocked($ip_address)) {
+            // IP is not blocked, no need to send unblock command
+            return true;
+        }
+        
         $data = [
             'ip_address' => $ip_address
         ];
