@@ -627,8 +627,8 @@ $stats = [
                     <div class="row mt-3">
                         <div class="col-md-6">
                             <label for="scheduleResource" class="form-label">Resource Name</label>
-                            <input type="text" class="form-control" id="scheduleResource" name="resource_name" placeholder="Leave blank for first available">
-                            <small class="form-text text-muted">For sites: domain name, for databases: database name. Use * for all resources.</small>
+                            <input type="text" class="form-control" id="scheduleResource" name="resource_name" placeholder="Leave blank to backup all">
+                            <small class="form-text text-muted">For sites: domain name, for databases: database name. Leave blank to backup all sites/databases for the user.</small>
                         </div>
                         <div class="col-md-6">
                             <label for="scheduleTarget" class="form-label">Backup Target</label>
