@@ -344,7 +344,10 @@ if (php_sapi_name() === 'cli') {
 
     try {
         // First, clean up any stale uploads
-        cleanup_stale_uploads((new mysqlmgmt())->getMySQLConnection());
+        $mysql = new mysqlmgmt();
+        $db = $mysql->getMySQLConnection();
+        $db->exec("USE whp");
+        cleanup_stale_uploads($db);
 
         // Process upload queue
         process_upload_queue();
